Enum pallet_chainlink_feed::pallet::Error [−][src]
pub enum Error<T> {
Show 39 variants
Overflow,
NotOracle,
NoOracles,
OracleNotEnabled,
OracleDisabled,
NotEnoughOracles,
ReportingOrder,
FeedNotFound,
RoundNotFound,
RequesterNotFound,
RoundNotSupersedable,
OracleNotFound,
NotAcceptingSubmissions,
SubmissionBelowMinimum,
SubmissionAboveMaximum,
DescriptionTooLong,
OraclesLimitExceeded,
AlreadyEnabled,
OwnerCannotChangeAdmin,
NotFeedOwner,
NotPendingOwner,
WrongBounds,
MaxExceededTotal,
DelayNotBelowCount,
NotAdmin,
NotPendingAdmin,
CannotRequestRoundYet,
NotAuthorizedRequester,
InsufficientFunds,
InsufficientReserve,
NotPalletAdmin,
NotPendingPalletAdmin,
CannotPruneRoundZero,
FeedLimitReached,
NotSupersedable,
InvalidRound,
NotFeedCreator,
NoPendingOwnershipTransfer,
MaxDebtReached,
// some variants omitted
}Expand description
Custom dispatch errors of this pallet.
Variants
A math operation lead to an overflow.
Given account id is not an oracle
A feed cannot be created without any oracles
The oracle cannot submit as it is not enabled yet.
The oracle has an ending round lower than the current round.
More oracles were passed for disabling than are present.
The oracle cannot report for past rounds.
Requested feed not present.
Requested round not present.
The specified account does not have requester permissions stored.
New round cannot be requested to supersede current round.
No oracle meta data found for the given account.
Submissions are not accepted for the specified round.
Oracle submission is below the minimum value.
Oracle submission is above the maximum value.
The description string is too long.
Tried to add too many oracles.
The oracle was already enabled.
The oracle address cannot change its associated admin.
Only the owner of a feed can change the configuration.
Only the pending owner of a feed can accept the transfer invitation.
The specified min/max pair was invalid.
The maximum number of oracles cannot exceed the amount of available oracles.
The round initiation delay cannot be equal to or greater than the number of oracles.
Sender is not admin. Admin privilege can only be transferred by the admin.
Only the pending admin can accept the transfer.
The requester cannot request a new round, yet.
No requester permissions associated with the given account.
Cannot withdraw funds.
Funds cannot be withdrawn as the reserve would be critically low.
Only the pallet admin account can call this extrinsic.
Only the pending admin can accept the transfer.
Round zero is not allowed to be pruned.
The maximum number of feeds was reached.
The round cannot be superseded by a new round.
The round cannot be started because it is not a valid new round.
The calling account is not allowed to create feeds.
No initiated transfer of ownership found, this will be thrown when the caller attempts to cancel a non existing ownership transfer.
The maximum debt of feeds was reached.
Implementations