Struct pallet_chainlink_feed::pallet::FeedConfig [−][src]
pub struct FeedConfig<AccountId: Parameter, Balance: Parameter, BlockNumber: Parameter, Value: Parameter, BoundedString> {Show 17 fields
pub owner: AccountId,
pub pending_owner: Option<AccountId>,
pub submission_value_bounds: (Value, Value),
pub submission_count_bounds: (u32, u32),
pub payment: Balance,
pub timeout: BlockNumber,
pub decimals: u8,
pub description: BoundedString,
pub restart_delay: u32,
pub reporting_round: RoundId,
pub latest_round: RoundId,
pub first_valid_round: Option<RoundId>,
pub oracle_count: u32,
pub pruning_window: u32,
pub next_round_to_prune: RoundId,
pub debt: Balance,
pub max_debt: Option<Balance>,
}Expand description
The configuration for an oracle feed.
Fields
owner: AccountIdOwner of this feed
pending_owner: Option<AccountId>The pending owner of this feed
submission_value_bounds: (Value, Value)Value bounds of oracle submissions
submission_count_bounds: (u32, u32)Count bounds of oracle submissions
payment: BalancePayment of oracle rounds
timeout: BlockNumberTimeout of rounds
decimals: u8Represents the number of decimals with which the feed is configured
description: BoundedStringThe description of this feed
restart_delay: u32The round initiation delay
reporting_round: RoundIdThe round oracles are currently reporting data for.
latest_round: RoundIdThe id of the latest round
first_valid_round: Option<RoundId>The id of the first round that contains non-default data
oracle_count: u32The amount of the oracles in this feed
pruning_window: u32Number of rounds to keep in storage for this feed.
next_round_to_prune: RoundIdKeeps track of the round that should be pruned next.
debt: BalanceTracks the amount of debt accumulated by the feed towards the oracles.
max_debt: Option<Balance>The maximum allowed debt a feed can accumulate
If this is a None value, the feed is not allowed to accumulate any
debt